==> dnet-modular-repositories-ui-3.0.5-20141203.095940-1-sources.jar: eu/dnetlib/functionality/modular/ui/repositories/objects/RepoInterfaceEntry.java <==
package eu.dnetlib.functionality.modular.ui.repositories.objects;

import java.util.List;

import com.google.common.collect.Lists;

public class RepoInterfaceEntry extends SimpleRepoInterfaceEntry {
	
	private String label;
	private String collDate = "";
	private int collTotal = 0;
	private String collMdId = "";
	private String aggrMdId = "";
    private String downloadDate = "";
    private int downloadTotal = 0;
    private String downloadObjId = "";
	private List<SimpleParamEntry> commonParams = Lists.newArrayList();
	private List<SimpleParamEntry> accessParams = Lists.newArrayList();
	private List<SimpleParamEntry> otherParams = Lists.newArrayList();
	private List<RepoMetaWfEntry> metaWFs = Lists.newArrayList();

	public String getLabel() {
		return label;
	}

	public void setLabel(final String label) {
		this.label = label;
	}

	public String getCollDate() {
		return collDate;
	}

	public void setCollDate(String collDate) {
		this.collDate = collDate;
	}

	public int getCollTotal() {
		return collTotal;
	}

	public void setCollTotal(int collTotal) {
		this.collTotal = collTotal;
	}
	
	public List<SimpleParamEntry> getCommonParams() {
		return commonParams;
	}

	public void setCommonParams(final List<SimpleParamEntry> commonParams) {
		this.commonParams = commonParams;
	}

	public List<SimpleParamEntry> getAccessParams() {
		return accessParams;
	}

	public void setAccessParams(final List<SimpleParamEntry> accessParams) {
		this.accessParams = accessParams;
	}

	public List<SimpleParamEntry> getOtherParams() {
		return otherParams;
	}

	public void setOtherParams(List<SimpleParamEntry> otherParams) {
		this.otherParams = otherParams;
	}
	
	public List<RepoMetaWfEntry> getMetaWFs() {
		return metaWFs;
	}

	public void setMetaWFs(final List<RepoMetaWfEntry> metaWFs) {
		this.metaWFs = metaWFs;
	}

	public String getAggrMdId() {
		return aggrMdId;
	}

	public void setAggrMdId(String aggrMdId) {
		this.aggrMdId = aggrMdId;
	}

	public String getCollMdId() {
		return collMdId;
	}

	public void setCollMdId(String collMdId) {
		this.collMdId = collMdId;
	}

    public String getDownloadDate() {
        return downloadDate;
    }

    public void setDownloadDate(String downloadDate) {
        this.downloadDate = downloadDate;
    }

    public int getDownloadTotal() {
        return downloadTotal;
    }

    public void setDownloadTotal(int downloadTotal) {
        this.downloadTotal = downloadTotal;
    }

    public String getDownloadObjId() {
        return downloadObjId;
    }

    public void setDownloadObjId(String downloadObjId) {
        this.downloadObjId = downloadObjId;
    }
}

==> dnet-modular-repositories-ui-4.0.4-20151120.145652-22-sources.jar: eu/dnetlib/functionality/modular/ui/repositories/objects/RepoInterfaceEntry.java <==
package eu.dnetlib.functionality.modular.ui.repositories.objects;

import java.util.List;

import com.google.common.collect.Lists;

import eu.dnetlib.enabling.datasources.rmi.SearchInterfacesEntry;

public class RepoInterfaceEntry extends SearchInterfacesEntry {

	private String label;
	private String collDate = "";
	private int collTotal = 0;
	private String collMdId = "";
	private String aggrMdId = "";
	private String downloadDate = "";
	private int downloadTotal = 0;
	private String downloadObjId = "";
	private List<SimpleParamEntry> commonParams = Lists.newArrayList();
	private List<SimpleParamEntry> accessParams = Lists.newArrayList();
	private List<SimpleParamEntry> otherParams = Lists.newArrayList();
	private List<RepoMetaWfEntry> metaWFs = Lists.newArrayList();

	public String getLabel() {
		return label;
	}

	public void setLabel(final String label) {
		this.label = label;
	}

	public String getCollDate() {
		return collDate;
	}

	public void setCollDate(final String collDate) {
		this.collDate = collDate;
	}

	public int getCollTotal() {
		return collTotal;
	}

	public void setCollTotal(final int collTotal) {
		this.collTotal = collTotal;
	}

	public List<SimpleParamEntry> getCommonParams() {
		return commonParams;
	}

	public void setCommonParams(final List<SimpleParamEntry> commonParams) {
		this.commonParams = commonParams;
	}

	public List<SimpleParamEntry> getAccessParams() {
		return accessParams;
	}

	public void setAccessParams(final List<SimpleParamEntry> accessParams) {
		this.accessParams = accessParams;
	}

	public List<SimpleParamEntry> getOtherParams() {
		return otherParams;
	}

	public void setOtherParams(final List<SimpleParamEntry> otherParams) {
		this.otherParams = otherParams;
	}

	public List<RepoMetaWfEntry> getMetaWFs() {
		return metaWFs;
	}

	public void setMetaWFs(final List<RepoMetaWfEntry> metaWFs) {
		this.metaWFs = metaWFs;
	}

	public String getAggrMdId() {
		return aggrMdId;
	}

	public void setAggrMdId(final String aggrMdId) {
		this.aggrMdId = aggrMdId;
	}

	public String getCollMdId() {
		return collMdId;
	}

	public void setCollMdId(final String collMdId) {
		this.collMdId = collMdId;
	}

	public String getDownloadDate() {
		return downloadDate;
	}

	public void setDownloadDate(final String downloadDate) {
		this.downloadDate = downloadDate;
	}

	public int getDownloadTotal() {
		return downloadTotal;
	}

	public void setDownloadTotal(final int downloadTotal) {
		this.downloadTotal = downloadTotal;
	}

	public String getDownloadObjId() {
		return downloadObjId;
	}

	public void setDownloadObjId(final String downloadObjId) {
		this.downloadObjId = downloadObjId;
	}
}
